django_auxilium.callback_mail.signals module
============================================

.. automodule:: django_auxilium.callback_mail.signals
    :members:
    :undoc-members:
    :show-inheritance:
